[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.15800478.svg)](https://doi.org/10.5281/zenodo.15800478)
[![GitHub License](https://img.shields.io/github/license/seedcase-project/seedcase-sprout)](https://github.com/seedcase-project/seedcase-sprout/blob/main/LICENSE.md)
[![PyPI Version](https://img.shields.io/pypi/v/seedcase-sprout)](https://pypi.org/project/seedcase-sprout/)
[![GitHub Release](https://img.shields.io/github/v/release/seedcase-project/seedcase-sprout)](https://github.com/seedcase-project/seedcase-sprout/releases/latest)
[![Supported Python Version from PEP 621 TOML](https://img.shields.io/python/required-version-toml?tomlFilePath=https%3A%2F%2Fraw.githubusercontent.com%2Fseedcase-project%2Fseedcase-sprout%2Frefs%2Fheads%2Fmain%2Fpyproject.toml)](https://github.com/seedcase-project/seedcase-sprout/blob/main/pyproject.toml)
[![OpenSSF Scorecard](https://api.scorecard.dev/projects/github.com/seedcase-project/seedcase-sprout/badge?raw=true)](https://scorecard.dev/viewer/?uri=github.com/seedcase-project/seedcase-sprout)
[![Build package](https://github.com/seedcase-project/seedcase-sprout/actions/workflows/build-package.yml/badge.svg)](https://github.com/seedcase-project/seedcase-sprout/actions/workflows/build-package.yml)
[![Build documentation](https://github.com/seedcase-project/seedcase-sprout/actions/workflows/build-website.yml/badge.svg)](https://github.com/seedcase-project/seedcase-sprout/actions/workflows/build-website.yml)
[![CodeQL](https://github.com/seedcase-project/seedcase-sprout/actions/workflows/github-code-scanning/codeql/badge.svg?branch=main)](https://github.com/seedcase-project/seedcase-sprout/actions/workflows/github-code-scanning/codeql)
[![pre-commit.ci status](https://results.pre-commit.ci/badge/github/seedcase-project/seedcase-sprout/main.svg)](https://results.pre-commit.ci/latest/github/seedcase-project/seedcase-sprout/main)
[![code coverage](https://raw.githubusercontent.com/seedcase-project/seedcase-sprout/coverage/coverage.svg?raw=true)](https://htmlpreview.github.io/?https://raw.githubusercontent.com/seedcase-project/seedcase-sprout/coverage/index.html)
[![lifecycle](https://lifecycle.r-lib.org/articles/figures/lifecycle-experimental.svg)](https://lifecycle.r-lib.org/articles/stages.html#experimental)
[![Project Status: Active – The project has reached a stable, usable state and is being actively developed.](https://www.repostatus.org/badges/latest/active.svg)](https://www.repostatus.org/#active)
[![OpenSSF Best Practices](https://www.bestpractices.dev/projects/10459/badge?raw=true)](https://www.bestpractices.dev/projects/10459)
